# localize plugin

[![fastlane Plugin Badge](https://rawcdn.githack.com/fastlane/fastlane/master/fastlane/assets/plugin-badge.svg)](https://rubygems.org/gems/fastlane-plugin-localize)

## Getting Started

This project is a [_fastlane_](https://github.com/fastlane/fastlane) plugin. To get started with `fastlane-plugin-localize`, add it to your project by running:

```bash
fastlane add_plugin localize
```

## About localize

Searches the code for extractable strings and allows interactive extraction to .strings file.

- Whitelists non-extracted strings for further runs
- Extracts as `NSLocalizedString` by default
- Support for [Swiftgen](https://github.com/SwiftGen/SwiftGen) by supplying `use_swiftgen:true`

![Example Gif](https://github.com/num42/fastlane-plugin-localize/raw/master/Localize.gif)

## Run from Commandline

To show all options:

```bash
fastlane action localize
```

Example:

```bash
fastlane run localize strings_file:"Sources/Base/Supporting Files/en.lproj/Localizable.strings" file_filter:"Swiftgen,Sourcery" use_swiftgen:"true"
```

## Run from Fastfile

```ruby
desc "Search for localizable strings"
lane :localize_strings do
  localize(
    strings_file: "Sources/Base/Supporting Files/en.lproj/Localizable.strings",
    file_filter: "Swiftgen,Sourcery", # filters files with these words in their path
    use_swiftgen: "true" # remove to use NSLocalizableString instead
  )
end
```

## Run tests for this plugin

To run both the tests, and code style validation, run

```
rake
```

To automatically fix many of the styling issues, use
```
rubocop -a
```

## Issues and Feedback

For any other issues and feedback about this plugin, please submit it to this repository.

## Troubleshooting

If you have trouble using plugins, check out the [Plugins Troubleshooting](https://docs.fastlane.tools/plugins/plugins-troubleshooting/) guide.

## Using _fastlane_ Plugins

For more information about how the `fastlane` plugin system works, check out the [Plugins documentation](https://docs.fastlane.tools/plugins/create-plugin/).

## About _fastlane_

_fastlane_ is the easiest way to automate beta deployments and releases for your iOS and Android apps. To learn more, check out [fastlane.tools](https://fastlane.tools).
